notifications_extras
==================================================
**Module**: :mod:`espressodb.notifications.templatetags.notifications_extras`

.. currentmodule:: espressodb.notifications.templatetags.notifications_extras

.. autosummary::
    bootstrap_level
    render_notification
    render_notification_links

------

.. automodule:: espressodb.notifications.templatetags.notifications_extras
    :members:
    :special-members:
